@@ -5,7 +5,7 @@ class Server:
 
     def start(self, flask_app):
         # Mount the application
-        cherrypy.tree.graft(app, "/")
+        cherrypy.tree.graft(flask_app, "/")
 
 
         class Static(object): pass
